@@ -32,7 +32,7 @@ from ..extra_configs import logging_config
 from ..irc import Irc
 
 if TYPE_CHECKING:
-    from ..pubsub import PubSubData, PubSubPointRedemption, PubSubBits, PubSubModerationAction, PubSubSubscription
+    from ..pubsub import PubSubData, PubSubPointRedemption, PubSubBits, PubSubModerationAction, PubSubSubscription, PubSubPollData
 
 
 # noinspection PyMethodMayBeStatic
@@ -211,6 +211,12 @@ class BaseBot:
         :param data: data specific to the user subscription
         """
 
+    async def on_pubsub_twitch_poll_update(self, raw: 'PubSubData', poll: 'PubSubPollData'):
+        """
+        triggered when a poll is start/updated/completed on a channel
+        :param poll: the poll that the triggered the event
+        """
+
     async def on_bot_shutdown(self):
         """
         triggered when the bot is shutdown
